<?php

namespace Litecms\MatrixLevel\Providers;

use Illuminate\Support\ServiceProvider;

class MatrixLevelServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'matrix_level');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'matrix_level');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.matrix_level', function ($app) {
            return $this->app->make('Litecms\MatrixLevel\MatrixLevel');
        });

                // Bind MatrixLevel to repository
        $this->app->bind(
            'Litecms\MatrixLevel\Interfaces\MatrixLevelRepositoryInterface',
            \Litecms\MatrixLevel\Repositories\Eloquent\MatrixLevelRepository::class
        );

        $this->app->register(\Litecms\MatrixLevel\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\MatrixLevel\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\MatrixLevel\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.matrix_level'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/matrix_level.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/matrix_level')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/matrix_level')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
